@@ -19,16 +19,17 @@
  **/
 
 
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 #include "ViewerToolbox.h"
 #include "ViewerPrefetchPolicy.h"
 #include "DecodedImageAdapter.h"
 #include "SeriesInformationAdapter.h"
 
-#include <Core/DicomFormat/DicomMap.h>
-#include <Core/OrthancException.h>
-#include <Core/SystemToolbox.h>
-#include <Core/Toolbox.h>
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include <DicomFormat/DicomMap.h>
+#include <Logging.h>
+#include <OrthancException.h>
+#include <SystemToolbox.h>
+#include <Toolbox.h>
 
 #include <boost/thread.hpp>
 #include <boost/lexical_cast.hpp>
@@ -55,9 +56,6 @@
 
 
 
-static OrthancPluginContext* context_ = NULL;
-
-
 class CacheContext
 {
 private:
@@ -99,7 +97,7 @@ private:
         // On the reception of a new instance, indalidate the parent series of the instance
         std::string uri = "/instances/" + std::string(instanceId);
         Json::Value instance;
-        if (OrthancPlugins::GetJsonFromOrthanc(instance, context_, uri))
+        if (OrthancPlugins::GetJsonFromOrthanc(instance, OrthancPlugins::GetGlobalContext(), uri))
         {
           std::string seriesId = instance["ParentSeries"].asString();
           cache->GetScheduler().Invalidate(OrthancPlugins::CacheBundle_SeriesInformation, seriesId);
@@ -115,7 +113,7 @@ public:
     boost::filesystem::path p(path);
     db_.Open((p / "cache.db").string());
 
-    cache_.reset(new OrthancPlugins::CacheManager(context_, db_, storage_));
+    cache_.reset(new OrthancPlugins::CacheManager(OrthancPlugins::GetGlobalContext(), db_, storage_));
     //cache_->SetSanityCheckEnabled(true);  // For debug
 
     scheduler_.reset(new OrthancPlugins::CacheScheduler(*cache_, 100));
@@ -168,7 +166,7 @@ static OrthancPluginErrorCode OnChangeCallback(OrthancPluginChangeType changeTyp
   }
   catch (std::runtime_error& e)
   {
-    OrthancPluginLogError(context_, e.what());
+    LOG(ERROR) << e.what();
     return OrthancPluginErrorCode_Success;  // Ignore error
   }
 }
@@ -184,7 +182,7 @@ static OrthancPluginErrorCode ServeCache(OrthancPluginRestOutput* output,
   {
     if (request->method != OrthancPluginHttpMethod_Get)
     {
-      OrthancPluginSendMethodNotAllowed(context_, output, "GET");
+      OrthancPluginSendMethodNotAllowed(OrthancPlugins::GetGlobalContext(), output, "GET");
       return OrthancPluginErrorCode_Success;
     }
 
@@ -193,28 +191,28 @@ static OrthancPluginErrorCode ServeCache(OrthancPluginRestOutput* output,
 
     if (cache_->GetScheduler().Access(content, bundle, id))
     {
-      OrthancPluginAnswerBuffer(context_, output, content.c_str(), content.size(), "application/json");
+      OrthancPluginAnswerBuffer(OrthancPlugins::GetGlobalContext(), output, content.c_str(), content.size(), "application/json");
     }
     else
     {
-      OrthancPluginSendHttpStatusCode(context_, output, 404);
+      OrthancPluginSendHttpStatusCode(OrthancPlugins::GetGlobalContext(), output, 404);
     }
 
     return OrthancPluginErrorCode_Success;
   }
   catch (Orthanc::OrthancException& e)
   {
-    OrthancPluginLogError(context_, e.What());
+    LOG(ERROR) << e.What();
     return OrthancPluginErrorCode_Plugin;
   }
   catch (std::runtime_error& e)
   {
-    OrthancPluginLogError(context_, e.what());
+    LOG(ERROR) << e.what();
     return OrthancPluginErrorCode_Plugin;
   }
   catch (boost::bad_lexical_cast&)
   {
-    OrthancPluginLogError(context_, "Bad lexical cast");
+    LOG(ERROR) << "Bad lexical cast";
     return OrthancPluginErrorCode_Plugin;
   }
 }
@@ -229,7 +227,7 @@ static OrthancPluginErrorCode ServeWebViewer(OrthancPluginRestOutput* output,
 {
   if (request->method != OrthancPluginHttpMethod_Get)
   {
-    OrthancPluginSendMethodNotAllowed(context_, output, "GET");
+    OrthancPluginSendMethodNotAllowed(OrthancPlugins::GetGlobalContext(), output, "GET");
     return OrthancPluginErrorCode_Success;
   }
 
@@ -241,13 +239,12 @@ static OrthancPluginErrorCode ServeWebViewer(OrthancPluginRestOutput* output,
   {
     Orthanc::SystemToolbox::ReadFile(s, path);
     const char* resource = s.size() ? s.c_str() : NULL;
-    OrthancPluginAnswerBuffer(context_, output, resource, s.size(), mime);
+    OrthancPluginAnswerBuffer(OrthancPlugins::GetGlobalContext(), output, resource, s.size(), mime);
   }
   catch (Orthanc::OrthancException&)
   {
-    std::string s = "Inexistent file in served folder: " + path;
-    OrthancPluginLogError(context_, s.c_str());
-    OrthancPluginSendHttpStatusCode(context_, output, 404);
+    LOG(ERROR) << "Inexistent file in served folder: " << path;
+    OrthancPluginSendHttpStatusCode(OrthancPlugins::GetGlobalContext(), output, 404);
   }
 
   return OrthancPluginErrorCode_Success;
@@ -263,7 +260,7 @@ static OrthancPluginErrorCode ServeEmbeddedFolder(OrthancPluginRestOutput* outpu
 {
   if (request->method != OrthancPluginHttpMethod_Get)
   {
-    OrthancPluginSendMethodNotAllowed(context_, output, "GET");
+    OrthancPluginSendMethodNotAllowed(OrthancPlugins::GetGlobalContext(), output, "GET");
     return OrthancPluginErrorCode_Success;
   }
 
@@ -276,15 +273,14 @@ static OrthancPluginErrorCode ServeEmbeddedFolder(OrthancPluginRestOutput* outpu
     Orthanc::EmbeddedResources::GetDirectoryResource(s, folder, path.c_str());
 
     const char* resource = s.size() ? s.c_str() : NULL;
-    OrthancPluginAnswerBuffer(context_, output, resource, s.size(), mime);
+    OrthancPluginAnswerBuffer(OrthancPlugins::GetGlobalContext(), output, resource, s.size(), mime);
 
     return OrthancPluginErrorCode_Success;
   }
   catch (std::runtime_error&)
   {
-    std::string s = "Unknown static resource in plugin: " + std::string(request->groups[0]);
-    OrthancPluginLogError(context_, s.c_str());
-    OrthancPluginSendHttpStatusCode(context_, output, 404);
+    LOG(ERROR) << "Unknown static resource in plugin: " << request->groups[0];
+    OrthancPluginSendHttpStatusCode(OrthancPlugins::GetGlobalContext(), output, 404);
     return OrthancPluginErrorCode_Success;
   }
 }
@@ -299,41 +295,41 @@ static OrthancPluginErrorCode IsStableSeries(OrthancPluginRestOutput* output,
   {
     if (request->method != OrthancPluginHttpMethod_Get)
     {
-      OrthancPluginSendMethodNotAllowed(context_, output, "GET");
+      OrthancPluginSendMethodNotAllowed(OrthancPlugins::GetGlobalContext(), output, "GET");
       return OrthancPluginErrorCode_Success;
     }
 
     const std::string id = request->groups[0];
     Json::Value series;
 
-    if (OrthancPlugins::GetJsonFromOrthanc(series, context_, "/series/" + id) &&
+    if (OrthancPlugins::GetJsonFromOrthanc(series, OrthancPlugins::GetGlobalContext(), "/series/" + id) &&
         series.type() == Json::objectValue)
     {
       bool value = (series["IsStable"].asBool() ||
                     series["Status"].asString() == "Complete");
       std::string answer = value ? "true" : "false";
-      OrthancPluginAnswerBuffer(context_, output, answer.c_str(), answer.size(), "application/json");
+      OrthancPluginAnswerBuffer(OrthancPlugins::GetGlobalContext(), output, answer.c_str(), answer.size(), "application/json");
     }
     else
     {
-      OrthancPluginSendHttpStatusCode(context_, output, 404);
+      OrthancPluginSendHttpStatusCode(OrthancPlugins::GetGlobalContext(), output, 404);
     }
 
     return OrthancPluginErrorCode_Success;
   }
   catch (Orthanc::OrthancException& e)
   {
-    OrthancPluginLogError(context_, e.What());
+    LOG(ERROR) << e.What();
     return OrthancPluginErrorCode_Plugin;
   }
   catch (std::runtime_error& e)
   {
-    OrthancPluginLogError(context_, e.what());
+    LOG(ERROR) << e.what();
     return OrthancPluginErrorCode_Plugin;
   }
   catch (boost::bad_lexical_cast&)
   {
-    OrthancPluginLogError(context_, "Bad lexical cast");
+    LOG(ERROR) << "Bad lexical cast";
     return OrthancPluginErrorCode_Plugin;
   }
 }
@@ -346,7 +342,7 @@ void ParseConfiguration(int& decodingThreads,
 {
   /* Read the configuration of the Web viewer */
   Json::Value configuration;
-  if (!OrthancPlugins::ReadConfiguration(configuration, context_))
+  if (!OrthancPlugins::ReadConfiguration(configuration, OrthancPlugins::GetGlobalContext()))
   {
     throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);    
   }
@@ -384,8 +380,8 @@ void ParseConfiguration(int& decodingThreads,
 static bool DisplayPerformanceWarning()
 {
   (void) DisplayPerformanceWarning;   // Disable warning about unused function
-  OrthancPluginLogWarning(context_, "Performance warning in Web viewer: "
-                          "Non-release build, runtime debug assertions are turned on");
+  LOG(WARNING) << "Performance warning in Web viewer: "
+               << "Non-release build, runtime debug assertions are turned on";
   return true;
 }
 
@@ -397,26 +393,31 @@ extern "C"
     using namespace OrthancPlugins;
 
     OrthancPlugins::SetGlobalContext(context);
+
+#if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 7, 2)
+    Orthanc::Logging::InitializePluginContext(context);
+#else
     Orthanc::Logging::Initialize(context);
-    context_ = context;
+#endif
+
     assert(DisplayPerformanceWarning());
-    OrthancPluginLogWarning(context_, "Initializing the Web viewer");
+    LOG(WARNING) << "Initializing the Web viewer";
 
 
     /* Check the version of the Orthanc core */
-    if (OrthancPluginCheckVersion(context_) == 0)
+    if (OrthancPluginCheckVersion(context) == 0)
     {
       char info[1024];
       sprintf(info, "Your version of Orthanc (%s) must be above %d.%d.%d to run this plugin",
-              context_->orthancVersion,
+              context->orthancVersion,
               ORTHANC_PLUGINS_MINIMAL_MAJOR_NUMBER,
               ORTHANC_PLUGINS_MINIMAL_MINOR_NUMBER,
               ORTHANC_PLUGINS_MINIMAL_REVISION_NUMBER);
-      OrthancPluginLogError(context_, info);
+      OrthancPluginLogError(context, info);
       return -1;
     }
 
-    OrthancPluginSetDescription(context_, "Provides a Web viewer of DICOM series within Orthanc.");
+    OrthancPluginSetDescription(context, "Provides a Web viewer of DICOM series within Orthanc.");
 
 
     /* By default, use half of the available processing cores for the decoding of DICOM images */
@@ -434,12 +435,10 @@ extern "C"
       boost::filesystem::path cachePath;
       ParseConfiguration(decodingThreads, cachePath, cacheSize);
 
-      std::string message = ("Web viewer using " + boost::lexical_cast<std::string>(decodingThreads) + 
-                             " threads for the decoding of the DICOM images");
-      OrthancPluginLogWarning(context_, message.c_str());
+      LOG(WARNING) << "Web viewer using " << decodingThreads
+                   << " threads for the decoding of the DICOM images";
 
-      message = "Storing the cache of the Web viewer in folder: " + cachePath.string();
-      OrthancPluginLogWarning(context_, message.c_str());
+      LOG(WARNING) << "Storing the cache of the Web viewer in folder: " << cachePath.string();
 
    
       /* Create the cache */
@@ -451,20 +450,20 @@ extern "C"
       std::string orthancVersion("unknown"), webViewerVersion("unknown");
       bool clear = false;
       if (!scheduler.LookupProperty(orthancVersion, CacheProperty_OrthancVersion) ||
-          orthancVersion != std::string(context_->orthancVersion))
+          orthancVersion != std::string(context->orthancVersion))
       {
-        std::string s = ("The version of Orthanc has changed from \"" + orthancVersion + "\" to \"" + 
-                         std::string(context_->orthancVersion) + "\": The cache of the Web viewer will be cleared");
-        OrthancPluginLogWarning(context_, s.c_str());
+        LOG(WARNING) << "The version of Orthanc has changed from \"" << orthancVersion
+                     << "\" to \"" << context->orthancVersion
+                     << "\": The cache of the Web viewer will be cleared";
         clear = true;
       }
 
       if (!scheduler.LookupProperty(webViewerVersion, CacheProperty_WebViewerVersion) ||
           webViewerVersion != std::string(ORTHANC_PLUGIN_VERSION))
       {
-        std::string s = ("The version of the Web viewer plugin has changed from \"" + webViewerVersion + "\" to \"" + 
-                         std::string(ORTHANC_PLUGIN_VERSION) + "\": The cache of the Web viewer will be cleared");
-        OrthancPluginLogWarning(context_, s.c_str());
+        LOG(WARNING) << "The version of the Web viewer plugin has changed from \""
+                     << webViewerVersion << "\" to \"" << ORTHANC_PLUGIN_VERSION
+                     << "\": The cache of the Web viewer will be cleared";
         clear = true;
       }
 
@@ -472,56 +471,55 @@ extern "C"
       /* Clear the cache if needed */
       if (clear)
       {
-        OrthancPluginLogWarning(context_, "Clearing the cache of the Web viewer");
+        LOG(WARNING) << "Clearing the cache of the Web viewer";
         scheduler.Clear();
-        scheduler.SetProperty(CacheProperty_OrthancVersion, context_->orthancVersion);
+        scheduler.SetProperty(CacheProperty_OrthancVersion, context->orthancVersion);
         scheduler.SetProperty(CacheProperty_WebViewerVersion, ORTHANC_PLUGIN_VERSION);
       }
       else
       {
-        OrthancPluginLogInfo(context_, "No change in the versions, no need to clear the cache of the Web viewer");
+        LOG(INFO) << "No change in the versions, no need to clear the cache of the Web viewer";
       }
 
 
       /* Configure the cache */
-      scheduler.RegisterPolicy(new ViewerPrefetchPolicy(context_));
+      scheduler.RegisterPolicy(new ViewerPrefetchPolicy(context));
       scheduler.Register(CacheBundle_SeriesInformation, 
-                         new SeriesInformationAdapter(context_, scheduler), 1);
+                         new SeriesInformationAdapter(context, scheduler), 1);
       scheduler.Register(CacheBundle_DecodedImage, 
-                         new DecodedImageAdapter(context_), decodingThreads);
+                         new DecodedImageAdapter(context), decodingThreads);
 
 
       /* Set the quotas */
       scheduler.SetQuota(CacheBundle_SeriesInformation, 1000, 0);    // Keep info about 1000 series
       
-      message = "Web viewer using a cache of " + boost::lexical_cast<std::string>(cacheSize) + " MB";
-      OrthancPluginLogWarning(context_, message.c_str());
+      LOG(WARNING) << "Web viewer using a cache of " << cacheSize << " MB";
 
       scheduler.SetQuota(CacheBundle_DecodedImage, 0, static_cast<uint64_t>(cacheSize) * 1024 * 1024);
     }
     catch (std::runtime_error& e)
     {
-      OrthancPluginLogError(context_, e.what());
+      LOG(ERROR) << e.what();
       return -1;
     }
     catch (Orthanc::OrthancException& e)
     {
       if (e.GetErrorCode() == Orthanc::ErrorCode_BadFileFormat)
       {
-        OrthancPluginLogError(context_, "Unable to read the configuration of the Web viewer plugin");
+        LOG(ERROR) << "Unable to read the configuration of the Web viewer plugin";
       }
       else
       {
-        OrthancPluginLogError(context_, e.What());
+        LOG(ERROR) << e.What();
       }
       return -1;
     }
 
 
     /* Install the callbacks */
-    OrthancPluginRegisterRestCallbackNoLock(context_, "/web-viewer/series/(.*)", ServeCache<CacheBundle_SeriesInformation>);
-    OrthancPluginRegisterRestCallbackNoLock(context_, "/web-viewer/is-stable-series/(.*)", IsStableSeries);
-    OrthancPluginRegisterRestCallbackNoLock(context_, "/web-viewer/instances/(.*)", ServeCache<CacheBundle_DecodedImage>);
+    OrthancPluginRegisterRestCallbackNoLock(context, "/web-viewer/series/(.*)", ServeCache<CacheBundle_SeriesInformation>);
+    OrthancPluginRegisterRestCallbackNoLock(context, "/web-viewer/is-stable-series/(.*)", IsStableSeries);
+    OrthancPluginRegisterRestCallbackNoLock(context, "/web-viewer/instances/(.*)", ServeCache<CacheBundle_DecodedImage>);
     OrthancPluginRegisterRestCallbackNoLock(context, "/web-viewer/libs/(.*)", ServeEmbeddedFolder<Orthanc::EmbeddedResources::JAVASCRIPT_LIBS>);
 
 #if ORTHANC_STANDALONE == 1
@@ -536,7 +534,7 @@ extern "C"
     /* Extend the default Orthanc Explorer with custom JavaScript */
     std::string explorer;
     Orthanc::EmbeddedResources::GetFileResource(explorer, Orthanc::EmbeddedResources::ORTHANC_EXPLORER);
-    OrthancPluginExtendOrthancExplorer(context_, explorer.c_str());
+    OrthancPluginExtendOrthancExplorer(context, explorer.c_str());
 
     return 0;
   }
@@ -544,13 +542,15 @@ extern "C"
 
   ORTHANC_PLUGINS_API void OrthancPluginFinalize()
   {
-    OrthancPluginLogWarning(context_, "Finalizing the Web viewer");
+    LOG(WARNING) << "Finalizing the Web viewer";
 
     if (cache_ != NULL)
     {
       delete cache_;
       cache_ = NULL;
     }
+
+    Orthanc::Logging::Finalize();
   }
 
 
