@@ -21,11 +21,12 @@
 
 #include "ViewerToolbox.h"
 
-#include <Core/OrthancException.h>
-#include <Core/Toolbox.h>
+#include <Logging.h>
+#include <OrthancException.h>
+#include <Toolbox.h>
 
-// Gain access to ORTHANC_PLUGINS_VERSION_IS_ABOVE if Orthanc SDK <= 1.3.0
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+// To gain access to ORTHANC_PLUGINS_VERSION_IS_ABOVE if Orthanc SDK <= 1.3.0
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
 #include <json/reader.h>
 #include <stdexcept>
@@ -218,7 +219,7 @@ namespace OrthancPlugins
       char* tmp = OrthancPluginGetConfiguration(context);
       if (tmp == NULL)
       {
-        OrthancPluginLogError(context, "Error while retrieving the configuration from Orthanc");
+        LOG(ERROR) << "Error while retrieving the configuration from Orthanc";
         return false;
       }
 
@@ -233,7 +234,7 @@ namespace OrthancPlugins
     }
     else
     {
-      OrthancPluginLogError(context, "Unable to parse the configuration");
+      LOG(ERROR) << "Unable to parse the configuration";
       return false;
     }
   }
